Module exception

Module exception 

Exception handling and conversion for HTTP requests

This module provides functionality to convert exceptions into HTTP responses, similar to Django’s django.core.handlers.exception.

Structs

DefaultExceptionHandler
Default exception handler implementation

Traits

ExceptionHandler
A trait for handling exceptions during request processing
IntoResponse
Trait for types that can be converted into HTTP responses

Functions

convert_exception_to_response
Convert an exception to an HTTP response

Type Aliases

ExceptionResult
Result type for exception handlers